@@ -349,3 +349,12 @@ tracker_memory_setrlimits (void)
 
 	return TRUE;
 }
+
+#ifndef HAVE_STRNLEN
+size_t
+strnlen (const char *str, size_t max)
+{
+	const char *end = memchr (str, 0, max);
+	return end ? (size_t)(end - str) : max;
+}
+#endif /* HAVE_STRNLEN */
